@@ -409,7 +409,7 @@ void Akregator::FolderExpansionHandler::setExpanded(const QModelIndex &idx, bool
         return;
     }
 
-    auto *const folder = qobject_cast<Akregator::Folder *>(node);
+    auto const folder = qobject_cast<Akregator::Folder *>(node);
     Q_ASSERT(folder);
     folder->setOpen(expanded);
 }
@@ -452,7 +452,7 @@ QStringList SubscriptionListModel::mimeTypes() const
 
 QMimeData *SubscriptionListModel::mimeData(const QModelIndexList &indexes) const
 {
-    auto *mimeData = new QMimeData;
+    auto mimeData = new QMimeData;
 
     QList<QUrl> urls;
     for (const QModelIndex &i : indexes) {
@@ -486,7 +486,7 @@ bool SubscriptionListModel::setData(const QModelIndex &idx, const QVariant &valu
     if (!node) {
         return false;
     }
-    auto *job = new RenameSubscriptionJob(this);
+    auto job = new RenameSubscriptionJob(this);
     job->setSubscriptionId(node->id());
     job->setName(value.toString());
     job->start();
@@ -529,7 +529,7 @@ bool SubscriptionListModel::dropMimeData(const QMimeData *data, Qt::DropAction a
     }
 
     // don't drop nodes into their own subtree
-    for (const int id : qAsConst(ids)) {
+    for (const int id : std::as_const(ids)) {
         const auto *const asFolder = qobject_cast<const Folder *>(m_feedList->findByID(id));
         if (asFolder && (asFolder == destFolder || asFolder->subtreeContains(destFolder))) {
             return false;
@@ -538,12 +538,12 @@ bool SubscriptionListModel::dropMimeData(const QMimeData *data, Qt::DropAction a
 
     const TreeNode *const after = droppedOnNode->isGroup() ? destFolder->childAt(row) : droppedOnNode;
 
-    for (const int id : qAsConst(ids)) {
+    for (const int id : std::as_const(ids)) {
         const TreeNode *const node = m_feedList->findByID(id);
         if (!node) {
             continue;
         }
-        auto *job = new MoveSubscriptionJob(this);
+        auto job = new MoveSubscriptionJob(this);
         job->setSubscriptionId(node->id());
         job->setDestination(destFolder->id(), after ? after->id() : 0);
         job->start();
